package list

import (
	"github.com/spf13/cobra"
	"k8s.io/utils/ptr"

	eiaapi "gitea.libretechconsulting.com/50W/eia-api-go/api"
	"gitea.libretechconsulting.com/50W/eia-api-go/cmd/eia-client/internal/util"
	"gitea.libretechconsulting.com/50W/eia-api-go/pkg/eia"
)

var ListCmd = &cobra.Command{
	Use:    "list <name>",
	Args:   cobra.RangeArgs(0, 1),
	Short:  "List Available EIA Series",
	PreRun: util.SetClient,
	Run:    runListCmd,
}

func runListCmd(cmd *cobra.Command, _ []string) {
	logger := util.Logger(cmd)

	client, err := util.Client(cmd)
	if err != nil {
		logger.Fatal().Err(err).Send()
	}

	// Facets
	ctx, cncl := util.RequestCtx(cmd)
	defer cncl()
	facets, err := client.GetV2AeoRoute1FacetWithResponse(ctx, "2023")
	if err != nil {
		logger.Fatal().Err(err).Send()
	}
	logger.Debug().Any("facets", facets.JSON200).Send()

	// Facet
	for _, option := range *facets.JSON200.Response.FacetOptions {
		ctx, cncl = util.RequestCtx(cmd)
		defer cncl()
		facet, err := client.GetV2AeoRoute1FacetFacetIdWithResponse(ctx, "2023", option)
		if err != nil {
			logger.Err(err).Send()
			return
		}
		logger.Debug().Str("facet", option).Any("options", facet.JSON200.Response.Facets).Send()
	}

	ctx, cncl = util.RequestCtx(cmd)
	defer cncl()
	resp, err := client.GetV2AeoRoute1DataWithResponse(ctx, "2023", &eiaapi.GetV2AeoRoute1DataParams{
		Start: ptr.To("2023"),
		End:   ptr.To("2023"),
		Facets: eia.NewFacets(
			&eia.Facet{
				Name: "regionId",
				Data: "5-4",
			},
			&eia.Facet{
				Name: "seriesId",
				Data: "gen_NA_elep_NA_nuc_NA_mcc_blnkwh",
			},
			&eia.Facet{
				Name: "seriesId",
				Data: "cap_NA_elep_NA_nup_NA_mcc_gw",
			},
			&eia.Facet{
				Name: "scenario",
				Data: "highmacro",
			},
		),
	})
	if err != nil {
		logger.Fatal().Err(err).Send()
	}

	// body, err := io.ReadAll(resp.Body)
	// defer resp.Body.Close()
	logger.Debug().Any("body", resp.JSON200).Send()
}
